@@ -17,9 +17,15 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
  *
- $Id: battstat.h,v 1.28 2005/01/14 04:06:40 ryanl Exp $
+ $Id: battstat.h,v 1.29 2005/03/20 10:20:55 kmaraas Exp $
  */
 
+
+#include <glib.h>
+#include <gdk/gdkgc.h>
+#include <gtk/gtktooltips.h>
+#include <gtk/gtkwidget.h>
+
 #define DEBUG 0
 
 #define PROGLEN 33.0
