@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.98 2005/02/27 18:11:14 ryanl Exp $
+ $Id: battstat_applet.c,v 1.99 2005/03/20 10:20:55 kmaraas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,8 +33,18 @@
 #include <time.h>
 #include <unistd.h>
 
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtkaccessible.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkicontheme.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktable.h>
+
 #include <glade/glade.h>
-#include <gnome.h>
 
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
