@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: properties.c,v 1.44 2005/01/14 04:06:40 ryanl Exp $
+ $Id: properties.c,v 1.45 2005/03/20 10:20:55 kmaraas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,14 +49,17 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <gnome.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkx.h>
 
 #include <glade/glade.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtktogglebutton.h>
 #include <gtk/gtkspinbutton.h>
 
 #include <gconf/gconf-client.h>
+#include <libgnome/gnome-init.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 /*#include <status-docklet.h>*/
