@@ -17,6 +17,9 @@
 #ifndef __GSWITCHIT_APPLET_H__
 #define __GSWITCHIT_APPLET_H__
 
+#include <gdk/gdkevents.h>
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtkwidget.h>
 #include <panel-applet.h>
 
 #include "libgswitchit/gswitchit_config.h"
@@ -27,7 +30,6 @@ typedef struct _GSwitchItApplet {
 	GtkWidget *appletAncestor;
 	GtkWidget *notebook;
 	GtkWidget *ebox;
-	GtkWidget *aboutDialog;
 } GSwitchItApplet;
 
 typedef struct _GSwitchItAppletGlobals {
