@@ -162,8 +162,8 @@
 	/* end font funcs and vars */
 
 	/* accessibility funcs and vars */
-	GtkWidget *access_drawing_area;
-	StockData *access_stock;
+	static GtkWidget *access_drawing_area;
+	static StockData *access_stock;
 
 	extern void set_relation (GtkWidget *widget, GtkLabel *label);
 	static void setup_refchild_nchildren(GtkWidget * vbox);
@@ -1962,7 +1962,6 @@ static gint updateOutput(gpointer data)
 		var2 = strtok(NULL,":");
 		var3 = strtok(NULL,":");
 		var4 = strtok(NULL,"");
-		g_free (buff);
 
 		if (!var3 || !var4)
 			return NULL;
@@ -1979,6 +1978,7 @@ static gint updateOutput(gpointer data)
 			buff2 = g_strdup(_("(No Change)"));
 			quote->color = WHITE;
 		}
+		g_free (buff);
 
 		return(buff2);
 	}
@@ -2184,7 +2184,7 @@ static gint updateOutput(gpointer data)
 		
 	}
 
-	gchar* gtik_get_text(void) {
+	static gchar* gtik_get_text(void) {
 		GArray *quotes = access_stock->quotes;
 		gchar **strs = NULL;
 		gchar *buff;
