@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.54 2005/02/24 09:01:53 kmaraas Exp $ */
+/* $Id: gweather-dialog.c,v 1.54.2.1 2005/03/30 06:17:41 ryanl Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -40,9 +40,6 @@ static void gweather_dialog_save_geometry (GWeatherApplet *gw_applet)
 	gtk_window_get_position (GTK_WINDOW (window), &x, &y);
 	gtk_window_get_size (GTK_WINDOW (window), &w, &h);
 
-	g_message ("gweather: saving spatial window location: %dx%d+%d+%d",
-			w, h, x, y);
-
 	panel_applet_gconf_set_int (gw_applet->applet,
 			"dialog_width", w, NULL);
 	panel_applet_gconf_set_int (gw_applet->applet,
@@ -95,9 +92,6 @@ static void gweather_dialog_load_geometry (GWeatherApplet *gw_applet)
 		return;
 	}
 	
-	g_message ("gweather: got spatial window location: %dx%d+%d+%d",
-			w, h, x, y);
-
 	gtk_window_resize (GTK_WINDOW (window), w, h);
 	gtk_window_move (GTK_WINDOW (window), x, y);
 }
