@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.86 2004/12/20 20:46:18 dcransto Exp $ */
+/* $Id: gweather-pref.c,v 1.88.2.3 2005/04/04 01:41:04 ryanl Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -36,6 +36,7 @@
 #include "gweather-pref.h"
 #include "gweather-applet.h"
 #include "gweather-xml.h"
+#include "gweather-dialog.h"
 
 #define NEVER_SENSITIVE		"never_sensitive"
 
@@ -202,8 +203,6 @@ static gint cmp_loc (const WeatherLocation *l1, const WeatherLocation *l2)
 /* Update pref dialog from gweather_pref */
 static gboolean update_dialog (GWeatherApplet *gw_applet)
 {
-    GtkCTreeNode *node;
-    
     g_return_val_if_fail(gw_applet->gweather_pref.location != NULL, FALSE);
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(gw_applet->pref_basic_update_spin), 
@@ -325,11 +324,10 @@ static void row_selected_cb (GtkTreeSelection *selection, gpointer data)
     if (!loc)
     	return;
 
-    panel_applet_gconf_set_string(gw_applet->applet, "location0", loc->untrans_name, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location1", loc->code, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location2", loc->zone, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location3", loc->radar, NULL);
-    panel_applet_gconf_set_string(gw_applet->applet, "location4", loc->trans_name, NULL);
+    panel_applet_gconf_set_string(gw_applet->applet, "location4", loc->name, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "coordinates", loc->coordinates, NULL);
     
     if (gw_applet->gweather_pref.location) {
@@ -356,7 +354,18 @@ static void load_locations (GWeatherApplet *gw_applet)
     
     /* load locations from xml file */
     current_location = weather_location_clone (gw_applet->gweather_pref.location);
-    gweather_xml_load_locations(tree, current_location);
+    if (gweather_xml_load_locations (tree, current_location))
+    {
+        GtkWidget *d;
+
+        d = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                    "Failed to load the Locations XML "
+                                    "database.  Please report this as "
+                                    "a bug.");
+        gtk_dialog_run (GTK_DIALOG (d));
+	gtk_widget_destroy (d);
+    }
+
     weather_location_free (current_location);
 }
 
@@ -541,14 +550,18 @@ static void parse_distance_string (const gchar *gconf_str, GWeatherPrefs *prefs)
 static void temp_combo_changed_cb (GtkComboBox *combo, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
-    TempUnit       new_unit, *old_unit;
-	
-	g_return_if_fail(gw_applet != NULL);
-    
-	old_unit = &gw_applet->gweather_pref.temperature_unit;	
-	new_unit = gtk_combo_box_get_active(combo) + 1;
+    TempUnit       new_unit, old_unit;
 
-	if (new_unit == *old_unit)
+    g_return_if_fail(gw_applet != NULL);
+
+    new_unit = gtk_combo_box_get_active(combo) + 1;
+
+    if (gw_applet->gweather_pref.use_temperature_default)
+        old_unit = TEMP_UNIT_DEFAULT;
+    else
+        old_unit = gw_applet->gweather_pref.temperature_unit;	
+
+    if (new_unit == old_unit)
         return;
 
     parse_temp_string (gconf_enum_to_string (temp_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
@@ -556,23 +569,27 @@ static void temp_combo_changed_cb (GtkComboBox *combo, gpointer data)
     panel_applet_gconf_set_string(gw_applet->applet, GCONF_TEMP_UNIT,
                                   gconf_enum_to_string (temp_unit_enum_map, new_unit),
                                   NULL);
-	
+
     gtk_label_set_text(GTK_LABEL(gw_applet->label), 
-	                   weather_info_get_temp_summary(gw_applet->gweather_info));
+                       weather_info_get_temp_summary(gw_applet->gweather_info));
     gweather_dialog_update (gw_applet);
 }
 
 static void speed_combo_changed_cb (GtkComboBox *combo, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
-    SpeedUnit      new_unit, *old_unit;
-	
-	g_return_if_fail(gw_applet != NULL);
-    
-	old_unit = &gw_applet->gweather_pref.speed_unit;	
-	new_unit = gtk_combo_box_get_active(combo) + 1;
+    SpeedUnit      new_unit, old_unit;
 
-	if (new_unit == *old_unit)
+	g_return_if_fail(gw_applet != NULL);
+
+    new_unit = gtk_combo_box_get_active(combo) + 1;
+
+    if (gw_applet->gweather_pref.use_speed_default)
+        old_unit = SPEED_UNIT_DEFAULT;
+    else
+        old_unit = gw_applet->gweather_pref.speed_unit;	
+
+    if (new_unit == old_unit)
         return;
 
     parse_speed_string (gconf_enum_to_string (speed_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
@@ -580,21 +597,25 @@ static void speed_combo_changed_cb (GtkComboBox *combo, gpointer data)
     panel_applet_gconf_set_string(gw_applet->applet, GCONF_SPEED_UNIT,
                                   gconf_enum_to_string (speed_unit_enum_map, new_unit),
                                   NULL);
-	
+
     gweather_dialog_update (gw_applet);
 }
 
 static void pres_combo_changed_cb (GtkComboBox *combo, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
-    PressureUnit   new_unit, *old_unit;
-	
-	g_return_if_fail(gw_applet != NULL);
-    
-	old_unit = &gw_applet->gweather_pref.pressure_unit;	
-	new_unit = gtk_combo_box_get_active(combo) + 1;
+    PressureUnit   new_unit, old_unit;
 
-	if (new_unit == *old_unit)
+    g_return_if_fail(gw_applet != NULL);
+
+    new_unit = gtk_combo_box_get_active(combo) + 1;
+
+    if (gw_applet->gweather_pref.use_pressure_default)
+        old_unit = PRESSURE_UNIT_DEFAULT;
+    else
+        old_unit = gw_applet->gweather_pref.pressure_unit;	
+
+    if (new_unit == old_unit)
         return;
 
     parse_pressure_string (gconf_enum_to_string (pressure_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
@@ -602,21 +623,25 @@ static void pres_combo_changed_cb (GtkComboBox *combo, gpointer data)
     panel_applet_gconf_set_string(gw_applet->applet, GCONF_PRESSURE_UNIT,
                                   gconf_enum_to_string (pressure_unit_enum_map, new_unit),
                                   NULL);
-	
+
     gweather_dialog_update (gw_applet);
 }
 
 static void dist_combo_changed_cb (GtkComboBox *combo, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
-    DistanceUnit   new_unit, *old_unit;
-	
-	g_return_if_fail(gw_applet != NULL);
-    
-	old_unit = &gw_applet->gweather_pref.distance_unit;	
-	new_unit = gtk_combo_box_get_active(combo) + 1;
+    DistanceUnit   new_unit, old_unit;
 
-	if (new_unit == *old_unit)
+    g_return_if_fail(gw_applet != NULL);
+
+    new_unit = gtk_combo_box_get_active(combo) + 1;
+
+    if (gw_applet->gweather_pref.use_distance_default)
+        old_unit = DISTANCE_UNIT_DEFAULT;
+    else
+        old_unit = gw_applet->gweather_pref.distance_unit;	
+
+    if (new_unit == old_unit)
         return;
 
     parse_distance_string (gconf_enum_to_string (distance_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
@@ -624,7 +649,7 @@ static void dist_combo_changed_cb (GtkComboBox *combo, gpointer data)
     panel_applet_gconf_set_string(gw_applet->applet, GCONF_DISTANCE_UNIT,
                                   gconf_enum_to_string (distance_unit_enum_map, new_unit),
                                   NULL);
-	
+
     gweather_dialog_update (gw_applet);
 }
 
@@ -778,7 +803,6 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkObject *pref_basic_update_spin_adj;
     GtkWidget *pref_basic_update_sec_lbl;
     GtkWidget *pref_basic_note_lbl;
-    GtkWidget *pref_net_note_lbl;    
     GtkWidget *pref_loc_hbox;
     GtkWidget *pref_loc_note_lbl;
     GtkWidget *scrolled_window;
@@ -1121,7 +1145,6 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
 {
     GError *error = NULL;
 	gchar  *gconf_str = NULL;
-	gint   value = 0;
 	GWeatherPrefs *prefs = &(gw_applet->gweather_pref);
 
 	/* Assume we use unit defaults */
