@@ -26,9 +26,19 @@
 
 #include <string.h>
 
-#include <libgnomeui/libgnomeui.h>
+#include <glib-object.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
+
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkicontheme.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkrange.h>
+#include <gtk/gtktooltips.h>
+#include <gtk/gtkwidget.h>
+
+#include <gconf/gconf-client.h>
+
+#include <libgnome/gnome-help.h>
 
 #include "applet.h"
 #include "keys.h"
@@ -130,7 +140,7 @@ gnome_volume_applet_get_type (void)
  */
 
 static inline void
-flip_byte (gchar *one, gchar *two)
+flip_byte (guchar *one, guchar *two)
 {
   gint temp;
 
@@ -140,7 +150,7 @@ flip_byte (gchar *one, gchar *two)
 }
 
 static inline void
-flip_pixel (gchar *line, gint pixel, gint width, gint bpp)
+flip_pixel (guchar *line, gint pixel, gint width, gint bpp)
 {
   gint n;
 
@@ -156,7 +166,7 @@ flip (GdkPixbuf *pix)
        h = gdk_pixbuf_get_height (pix),
        x, y, stride = gdk_pixbuf_get_rowstride (pix),
        bpp = gdk_pixbuf_get_n_channels (pix);
-  gchar *data = gdk_pixbuf_get_pixels (pix);
+  guchar *data = gdk_pixbuf_get_pixels (pix);
 
   for (y = 0; y < h; y++) {
     for (x = 0; x < (w / 2); x++) {
@@ -599,10 +609,14 @@ static void
 gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
 {
   BonoboUIComponent *component;
-  gboolean mute = (GST_MIXER_TRACK_HAS_FLAG (applet->track,
-			GST_MIXER_TRACK_MUTE));
+  gboolean mute = applet->state & 1;
+  GtkAdjustment *adj = gtk_range_get_adjustment (applet->dock->scale);
 
   gst_mixer_set_mute (applet->mixer, applet->track, !mute);
+  if (mute) {
+    /* sync back actual volume */
+    cb_volume (adj, applet);
+  }
 
   /* update component */
   component = panel_applet_get_popup_component (PANEL_APPLET (applet));
@@ -899,7 +913,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
 {
   BonoboUIComponent *component;
   GdkPixbuf *pixbuf;
-  gint n, *volumes, volume = 0;
+  gint n, *volumes, volume = 0, orig_vol;
   gboolean mute;
 
   /* build-up phase */
@@ -910,12 +924,13 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
   gst_mixer_get_volume (applet->mixer, applet->track, volumes);
   for (n = 0; n < applet->track->num_channels; n++)
     volume += volumes[n];
-  volume /= applet->track->num_channels;
   g_free (volumes);
   mute = GST_MIXER_TRACK_HAS_FLAG (applet->track,
 				   GST_MIXER_TRACK_MUTE);
   if (volume == 0)
     mute = TRUE;
+  orig_vol = volume;
+  volume /= applet->track->num_channels;
 
   n = 4 * volume / (applet->track->max_volume -
       applet->track->min_volume) + 1;
@@ -936,7 +951,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
   }
 
   applet->lock = TRUE;
-  if (volume > 0)
+  if (orig_vol > 0)
     gtk_range_set_value (applet->dock->scale, volume);
   applet->lock = FALSE;
 
@@ -1140,8 +1155,7 @@ cb_ui_event (BonoboUIComponent *comp,
 
   if (!strcmp (verbname, "Mute")) {
     /* mute will have a value of 4 without the ? TRUE : FALSE bit... */
-    gboolean mute = (GST_MIXER_TRACK_HAS_FLAG (applet->track,
-                        GST_MIXER_TRACK_MUTE)) ? TRUE : FALSE,
+    gboolean mute = applet->state & 1,
              want_mute = !strcmp (state_string, "1") ? TRUE : FALSE;
 
     if (mute != want_mute)
