@@ -142,7 +142,7 @@ static const BonoboUIVerb menu_verbs[] = {
   BONOBO_UI_VERB_END
 };
 
-GType
+static GType
 modem_applet_get_type (void)
 {
   static GType type = 0;
@@ -281,7 +281,7 @@ modem_applet_change_background (PanelApplet *app,
   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
   rc_style = gtk_rc_style_new ();
   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  g_object_unref (rc_style);
+  gtk_rc_style_unref (rc_style);
 
   switch (type)
     {
@@ -299,6 +299,7 @@ modem_applet_change_background (PanelApplet *app,
 
       style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
       gtk_widget_set_style (GTK_WIDGET (applet), style);
+      g_object_unref (style);
       break;
     }
 }
