@@ -18,9 +18,14 @@
  */
 
 #include <config.h>
-#include <stickynotes_applet.h>
-#include <stickynotes_applet_callbacks.h>
-#include <stickynotes.h>
+#include "stickynotes_applet.h"
+#include "stickynotes_applet_callbacks.h"
+#include "stickynotes.h"
+
+#include <gtk/gtkiconfactory.h>
+#include <libgnomeui/gnome-client.h>
+#include <libgnomeui/gnome-icon-theme.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 StickyNotes *stickynotes = NULL;
 
